import numpy as np
from astropy.table import Table

class SPHERExRef2Eazy:
    bands_ref = [
        'Gaia_G', 'Gaia_BP', 'Gaia_RP',
        'WISE_W1', 'WISE_W2', 'WISE_W3', 'WISE_W4',
        '2MASS_J', '2MASS_H', '2MASS_Ks',
        'PS1_g', 'PS1_r', 'PS1_i', 'PS1_z', 'PS1_y',
        'LS_g', 'LS_r', 'LS_z',
    ]

    # bands_err = [b + '_error' for b in bands_ref]

    bands_eazy = [
        'Gaia_G', 'Gaia_BP', 'Gaia_RP',
        'WISE_W1', 'WISE_W2', 'WISE_W3', 'WISE_W4',
        '2MASS_J', '2MASS_H', '2MASS_Ks',
        'PS1_g', 'PS1_r', 'PS1_i', 'PS1_z', 'PS1_y',
        'DECam_g', 'DECam_r', 'DECam_z',
    ]

    column_names = ["id"] + [c for b in bands_eazy for c in (f"f_{b}", f"e_{b}")] + ["z_spec"]

    def get_eazy_table(self, r):
        # r = sel_phot
        cols = [r['SPHERExRefID']]
        n = len(cols[0])

        for b in self.bands_ref:
            # Do not use Legacy Survey, instead use PanSTARRS
            if b in ['LS_g', 'LS_r', 'LS_z']:
                flux = flux_err = np.zeros((n,)) - 9999
            else:
                flux, flux_err = r[b], r[f"{b}_error"]
            cols.append(flux)
            cols.append(flux_err)
        cols.append(r["z"])

        cattab = Table(cols, names=self.column_names)
        return cattab

    def get_empty_eazy_table(self):
        from collections import defaultdict
        d = defaultdict(list)
        return self.get_eazy_table(d)
